/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2020. All rights reserved.
 */
//
//  Huawei IdeaShare SDK Engine SDK
//
//  Copyright (c) 2020 Huawei.io. All rights reserved.
//

#ifndef IDEA_ENGINE_H
#define IDEA_ENGINE_H

#ifndef IDEA_SHARE_EXPORT
#define IDEA_SHARE_EXPORT
#endif


#include "IServiceController.h"
#include "IEventHandler.h"
#include <string>
#include <list>
#include <atomic>
#include "IdeaShareDef.h"

using namespace std;

namespace Huawei {
    namespace Idea {
        class IDEA_SHARE_API IShareEventHandler : public IEventHandler {
        public:
            virtual ~IShareEventHandler() {}
            /* DiscoverӿڵĻصӿ */
            virtual void OnDiscoverResult(DiscoverResult* discoverResult) {}
            virtual void OnDiscoverFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* ConnectӿڵĻصӿ */
            virtual void OnConnectResult(DeviceInfo* deviceInfo) {}
            virtual void OnConnectFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* DisconnectӿڵĻصӿ */
            virtual void OnDisconnectResult(int reason) {}
            virtual void OnDisconnectFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* StartSharingӿڵĻصӿ */
            virtual void OnSharePlayResult() {}
            virtual void OnSharePlayFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* StopSharingӿڵĻصӿ */
            virtual void OnShareStopResult(int reason) {}
            virtual void OnShareStopFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* GetRemoteServiceStatusӿڵĻصӿ */
            virtual void OnGetRemoteServiceStatusResult(RemoteServiceStatus* remoteServiceStatus) {}
            virtual void OnGetRemoteServiceStatusFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* SetRemoteMicMuteӿڵĻصӿ */
            virtual void OnSetRemoteMicMuteResult(int result) {}
            virtual void OnSetRemoteMicMuteFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* SetRemoteSpeakerVolumeӿڵĻصӿ */
            virtual void OnSetRemoteSpeakerVolumeResult(int result) {}
            virtual void OnSetRemoteSpeakerVolumeFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* SetRemoteSpeakerMuteӿڵĻصӿ */
            virtual void OnSetRemoteSpeakerMuteResult(int result) {}
            virtual void OnSetRemoteSpeakerMuteFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* SetRemoteCameraMuteӿڵĻصӿ */
            virtual void OnSetRemoteCameraMuteResult(int result) {}
            virtual void OnSetRemoteCameraMuteFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* LeaveConferenceӿڵĻصӿ */
            virtual void OnSetLeaveConferenceResult(int result) {}
            virtual void OnSetLeaveConferenceFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* EndConferenceӿڵĻصӿ */
            virtual void OnSetEndConferenceResult(int result) {}
            virtual void OnSetEndConferenceFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* GetSDKLatestVersionӿڵĻصӿ */
            virtual void OnGetSDKLatestVersionResult(std::string version) {}
            virtual void OnGetSDKLatestVersionFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* tlsӿʧܵĻصӿ */
            virtual void OnSetTLSFailed(ShareAppErr errorCode, std::string errorMsg) {}

            /* ʽӿڵĻصӿ */
            virtual void OnSetMouseShapeResult(int result) {}
            virtual void OnSetMouseShapeFailed(ShareAppErr errorCode, std::string errorMsg) {}
            /* ״̬Ϣ仯֪ͨ¼ */
            virtual void OnRemoteServiceStatusChangedNotify(RemoteServiceStatus *remoteServiceStatus, int index) {}

            /* ǰIdeaHub״̬¼ϱӿ */
            virtual void OnDevConfStateNotify(ConfSate confState, AuxState auxState) {}

            /* Ͷ״̬仯֪ͨϱӿ */
            virtual void OnShareStatusChangedNotify(ShareAppServerStatus status, ShareAppErr reason) {}

            /* ¼ʧʱͳһϱĽӿ */
            virtual void OnError(ShareAppErr errorCode, std::string errorMsg, void* extralInfo) {}
        };

        class IDEA_SHARE_API ShareServiceController : public IServiceController {
        public:
            static ShareServiceController* GetInstance();
            ~ShareServiceController();
            /* ־ */
            int SetLog(const LogInfo &logInfo);
            /* TLS */
            int SetTLS(const ShareTlsInfo &tlsInfo);
            /* ʼ */
            int Create(const AppInfo &appInfo, IEventHandler* eventHandler);
            /* ȥʼ */
            int Destory();
            /* Ͷ豸 */
            int SetDeviceType(ShareDeviceType shareDeviceType);
            /* Ͷ */
            int SetPolicy(const SharePolicy& sharePolicy);
            /* Ͷip */
            int Discover(std::string castCode, std::string address, int port);
            /*  */
            int Connect(list<std::string> addressList, int port, std::string password);
            /* Ͽ */
            int Disconnect();
            /* Ͷ */
            int SetDisplayScreen(ShareAppScreenType screenChoice);
            /* ʼͶ */
            int StartSharing();
            /* ֹͣͶ */
            int StopSharing();
            /* ȡԶ̷״̬Ϣ */
            int GetRemoteServiceStatus();
            /* \ر˷ */
            int SetRemoteMicMute(bool isMute);
            /*  */
            int SetRemoteSpeakerVolume(int volume);
            /* \ر */
            int SetRemoteSpeakerMute(bool isSpeakerMute);
            /* \ر */
            int SetRemoteCameraMute(bool isCameraMute);
            /* 뿪 */
            int LeaveConference();
            /*  */
            int EndConference();
            /* ȡͶ״̬ */
            int GetShareStatus();
            /* ȡSDK汾 */
            std::string GetSDKVersion();
            /* ȡµķ汾Ϣ */
            int GetSDKLatestVersion();
            /* ʽ */
            int SetMouseShape(ShareMouseShape mouseShape);
            /* ȫ¼ص */
            IShareEventHandler* mEventHandler;
            /* Ԫ */
            friend void ProcessNotifyCallback(uint32_t msgid, uint32_t param1, uint32_t param2, const void *data);
            /* ȫֻص */
            void NotifyCallback(uint32_t msgid, uint32_t param1, uint32_t param2, const void *data);
        private:
            /* ˽й췽ֹnew */
            ShareServiceController();
            /* ȫ¼ص */
            static ShareServiceController *mControllerInstance;
            /* Ƿڹ */
            std::atomic<bool> m_IsSharing{ false };
        };
    } // namespace Idea
} // namespace Huawei

#endif