/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2020. All rights reserved.
 */
 /* *
  * @file IdeaShareDef.h
  *
  * Copyright(C), 2012-2015, Huawei Tech. Co., Ltd. ALL RIGHTS RESERVED. \n
  *
  * ideashare wrapper sdk \n
  */
#ifndef __IDEASHARE_CLIENT_DEF_H__
#define __IDEASHARE_CLIENT_DEF_H__
#include<string>
#include<iostream>
#include <list>
#include <algorithm>
using namespace std;

#ifdef WIN32

#ifdef IDEA_SHARE_API
#undef IDEA_SHARE_API
#endif

#ifdef  IDEA_SHARE_EXPORT
#define IDEA_SHARE_API __declspec(dllexport)
#else
#define IDEA_SHARE_API __declspec(dllimport)
#endif
#else /* WIN32 */
#define IDEA_SHARE_API  __attribute__ ((__visibility__ ("default")))
#endif

#ifdef __cplusplus
#if __cplusplus
extern "C" {
#endif /*  __cpluscplus */
#endif /*  __cpluscplus */

/* ******************************************************************************
 * 곣
 * ***************************************************************************** */

/* ******************************************************************************
 * öͶ
 * ***************************************************************************** */
/**
 * [en]This enumeration is used to describe the log level
 * [cn]־
 */
typedef enum {
    IDEA_LEVEL_ERROR = 0,    /** < [en]Indicates the error level
                                  <br>[cn]󼶱 */
    IDEA_LEVEL_WARNING,      /** < [en]Indicates the warning level
                                  <br>[cn]漶 */
    IDEA_LEVEL_INFO,         /** < [en]Indicates the info level
                                  <br>[cn]Ϣ */
    IDEA_LEVEL_DEBUG         /** < [en]Indicates the debug level
                                  <br>[cn]Լ */
} LogLevel;

/**
 * [cn]ERROR
 */
typedef enum  {
    DISCOVER_ERROR = 0,              // 豸ִ 0
    CONNECT_ERROR,                   // Ӵ 1
    DISCONNECT_ERROR,                // ϿӴ 2
    SHARE_PLAY_ERROR,                // Ͷ 3
    SHARE_STOP_ERROR,                // ֹͣͶ 4
    GET_REMOTE_SERVICE_STATUS_ERROR, // ңѯ 5
    SET_REMOTE_MIC_MUTE_ERROR,       // \ر˷ 6
    SET_REMOTE_SPEAKER_VOLUME_ERROR, //  7
    SET_REMOTE_SPEAKER_MUTE_ERROR,   // \ر 8
    SET_REMOTE_CAMERA_MUTE_ERROR,    // \ر  9
    LEAVE_CONFERENCE_ERROR,          // 뿪 10
    END_CONFERENCE_ERROR,            //  11
    GET_SDK_LATEST_VERSION_ERROR,    // ȡSDK°汾 12
    PROCESS_CONNECTING_ERROR,        // ڴ 13
    IN_CONNECTION_ERROR,             // ͻѴ 14
    PROJECTION_CODE_ERROR,           // ͶӰ +ĸ 15
    AUTH_ERROR,                      // Ȩʧ 16
    CLIENT_IS_LOCKED_ERROR,          // ͻ˱ 17
    CONNECT_BUSY_ERROR,              // նæµ 18
    CONNECT_UPDATING_ERROR,          // ն 19
    WEB_DENY_ERROR,                  // WEB 20
    NO_COMMON_DATA_CAP_ERROR,        // Ϳͻûи 21
    GET_TOKEN_FAILD_ERROR,           // ȡʧ 22
    LOW_BANDWIDTH_ERROR,             // ͣ޷͸ 23
    CONF_NO_DATA_CAP_ERROR,          // ޸ 24
    MULTICONNECT_BUSY_ERROR,         // նڴͣҲܸ͸ 25
    EUA_AUTH_ERROR,                  // EUAȨʧ 26
    EUA_IS_LOCKED_ERROR,             // EUAͻ˱ 27
    SET_MOUSE_SHAPE_ERROR,           // ʽʧ 28
    BUTT                             // default
} ShareAppErr;

/* ָʾ */
typedef enum {
    SERVER_STATUS_CONNECT,
    SERVER_STATUS_SHARE,
    SERVER_STATUS_STOP_SHARE,
    SERVER_STATUS_DISCONNECT,

    SERVER_STATUS_BUTT
} ShareAppServerStatus;

/* ָʾ */
typedef enum {
    SCREEN_PRIMARY,
    SCREEN_SECONDARY
} ShareAppScreenType;

typedef enum {
    FLUENCY_FIRST = 0,  /*  */
    QUAITY_CLEAR_FIRST, /*  */
    QUAITY_ADAPTIVE,    /* Ӧ */
} ShareAppDefinationQuality;

typedef enum {
    SHARE_MOUSE_SHAPE_HIDE = 0, // 
    SHARE_MOUSE_SHAPE_WHITE_ARROW = 252, // ɫͷ,windows
    SHARE_MOUSE_SHAPE_LASER_POINTER = 255 // ,Ĭϸɫ
} ShareMouseShape;
/* ******************************************************************************
 * ṹ嶨
 * ***************************************************************************** */
typedef struct {
    std::string appId; // 󳤶128
    std::string exePath; // 󳤶128
} AppInfo;

typedef struct {
    std::string path; // 󳤶225
    LogLevel logLevel;
    bool enable;   // Ƿ־
} LogInfo;

typedef struct {
    int result;
    std::string password;
    std::list<std::string> addressList;
} DiscoverResult;

typedef struct {
    unsigned int isMute;
    unsigned int isCameraMute;
    int  volume;
    unsigned int isSpeakerMute;
    unsigned int isChairman;
    unsigned int isBase;
} RemoteServiceStatus;

typedef enum {
    IDEA_SHARE_CONNECTED,  /* * <  */
    IDEA_SHARE_SHARING,    /* * <  */
    IDEA_SHARE_STOPSHARING, /* * < ֹͣ */
    IDEA_SHARE_DISCONNECT, /* * <  */
    IDEA_SHARE_BUTT
} IdeaShareStatus;

typedef enum {
    CONF_IDLE = 0,              // 
    CONF_BUSY,                   // æ
} ConfSate;

typedef enum {
    AUX_IDLE = 0,              // 
    AUX_BUSY,                   // æ
} AuxState;

/* *
 * ϱṹ
 */
typedef struct {
    std::string deviceAddress;   /* *< ն˵ַIPַ or  */
    std::string deviceName;     /* *< ն(᳡) */
    unsigned int isSupportRemote; /* *< ն˲Ƿ֧ң VOS_TRUE:֧,VOS_FALSE:֧֡TUPĿǰĬΪVOS_TRUE֧ */
} DeviceInfo;

typedef struct {
    ShareAppDefinationQuality shareQuality; // 
    bool isShareAudio; /* 0ʾƵ1ʾƵ */
    bool isCompatibility; /* 0ʾԣ1ʾ */
} SharePolicy;

typedef enum {
    NON_PROJECTOR = 0,
    PROJECTOR,
    DEVICE_BUTT
} ShareDeviceType;

/* ֤ģʽ */
typedef enum {
    TLS_VERIFY_MODE_NONE = 0, /* * ֤ */
    TLS_VERIFY_MODE_SERVER,   /* * ֤ */
    TLS_VERIFY_MODE_CLIENT,   /* * ֤ͻ */
    TLS_VERIFY_MODE_BOTH,     /* * ͻˣ˫֤ */
    TLS_VERIFY_MODE_BUTT
} ShareClientTlsVerifyMode;

typedef struct {
    std::string caCertpath;        /* * < ca֤,󳤶256 */
    std::string clientCertpath;    /* * < ͻ֤,󳤶256 */
    ShareClientTlsVerifyMode verifyMode;                /* * < Уģʽ */
} ShareTlsInfo;

#ifdef __cplusplus
#if __cplusplus
}
#endif /*  __cpluscplus */
#endif /*  __cpluscplus */

#endif